---
name: Bug report
about: Create a report to help us improve
title: ""
labels: Bug
assignees: ""
---

## Bug description

<!-- A clear and concise description of what the bug is. -->

<!-- If applicable, add a log or screenshot to help explain your problem. -->

## How to reproduce?

Steps to reproduce the behavior:

1.

## Expected behavior

<!-- A clear and concise description of what you expected to happen. -->

## System info

Bug resulted on the following system:

- OS: <!-- e.g. macOS, WSL Ubuntu, ...-->
- Version <!-- e.g. 10.15, 20.04, ... -->
- Python version: <!-- e.g. 3.7, 3.8, ... -->
- Virtual environment: <!-- e.g. venv, Conda, pip user install, ... -->
